@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonadilivequeryhelpers.h"
@@ -39,11 +21,11 @@ LiveQueryHelpers::LiveQueryHelpers(const SerializerInterface::Ptr &serializer,
 {
 }
 
-LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchAllCollections() const
+LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchAllCollections(QObject *parent) const
 {
     auto storage = m_storage;
-    return [storage] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
-        auto job = storage->fetchCollections(Collection::root(), StorageInterface::Recursive);
+    return [storage, parent] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
+        auto job = storage->fetchCollections(Collection::root(), StorageInterface::Recursive, parent);
         Utils::JobHandler::install(job->kjob(), [job, add] {
             if (job->kjob()->error())
                 return;
@@ -54,11 +36,11 @@ LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchAllCollections(
     };
 }
 
-LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchCollections(const Collection &root) const
+LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchCollections(const Collection &root, QObject *parent) const
 {
     auto storage = m_storage;
-    return [storage, root] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
-        auto job = storage->fetchCollections(root, StorageInterface::Recursive);
+    return [storage, root, parent] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
+        auto job = storage->fetchCollections(root, StorageInterface::Recursive, parent);
         Utils::JobHandler::install(job->kjob(), [root, job, add] {
             if (job->kjob()->error())
                 return;
@@ -78,14 +60,15 @@ LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchCollections(con
     };
 }
 
-LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems() const
+LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems(QObject *parent) const
 {
     auto serializer = m_serializer;
     auto storage = m_storage;
-    return [serializer, storage] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
+    return [serializer, storage, parent] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
         auto job = storage->fetchCollections(Akonadi::Collection::root(),
-                                             StorageInterface::Recursive);
-        Utils::JobHandler::install(job->kjob(), [serializer, storage, job, add] {
+                                             StorageInterface::Recursive,
+                                             parent);
+        Utils::JobHandler::install(job->kjob(), [serializer, storage, job, add, parent] {
             if (job->kjob()->error() != KJob::NoError)
                 return;
 
@@ -93,7 +76,7 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems() const
                 if (!serializer->isSelectedCollection(collection))
                     continue;
 
-                auto job = storage->fetchItems(collection);
+                auto job = storage->fetchItems(collection, parent);
                 Utils::JobHandler::install(job->kjob(), [job, add] {
                     if (job->kjob()->error() != KJob::NoError)
                         return;
@@ -106,11 +89,11 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems() const
     };
 }
 
-LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems(const Collection &collection) const
+LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems(const Collection &collection, QObject *parent) const
 {
     auto storage = m_storage;
-    return [storage, collection] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
-        auto job = storage->fetchItems(collection);
+    return [storage, collection, parent] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
+        auto job = storage->fetchItems(collection, parent);
         Utils::JobHandler::install(job->kjob(), [job, add] {
             if (job->kjob()->error() != KJob::NoError)
                 return;
@@ -121,9 +104,9 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItems(const Collectio
     };
 }
 
-LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItemsForContext(const Domain::Context::Ptr &context) const
+LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItemsForContext(const Domain::Context::Ptr &context, QObject *parent) const
 {
-    auto fetchFunction = fetchItems();
+    auto fetchFunction = fetchItems(parent);
     auto serializer = m_serializer;
 
     return [context, fetchFunction, serializer] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
@@ -135,7 +118,7 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchItemsForContext(const
     };
 }
 
-LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchTaskAndAncestors(Domain::Task::Ptr task) const
+LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchTaskAndAncestors(Domain::Task::Ptr task, QObject *parent) const
 {
     Akonadi::Item childItem = m_serializer->createItemFromTask(task);
     Q_ASSERT(childItem.parentCollection().isValid()); // do I really need a fetchItem first, like fetchSiblings does?
@@ -144,8 +127,8 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchTaskAndAncestors(Doma
     const Akonadi::Item::Id childId = childItem.id();
     auto storage = m_storage;
     auto serializer = m_serializer;
-    return [storage, serializer, childItem, childId] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
-        auto job = storage->fetchItems(childItem.parentCollection());
+    return [storage, serializer, childItem, childId, parent] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
+        auto job = storage->fetchItems(childItem.parentCollection(), parent);
         Utils::JobHandler::install(job->kjob(), [job, add, serializer, childId] {
             if (job->kjob()->error() != KJob::NoError)
                 return;
@@ -178,11 +161,11 @@ LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchTaskAndAncestors(Doma
     };
 }
 
-LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchItemCollection(const Item& item) const
+LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchItemCollection(const Item& item, QObject *parent) const
 {
     auto storage = m_storage;
-    return [storage, item] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
-        auto job = storage->fetchCollections(item.parentCollection(), StorageInterface::Base);
+    return [storage, item, parent] (const Domain::LiveQueryInput<Collection>::AddFunction &add) {
+        auto job = storage->fetchCollections(item.parentCollection(), StorageInterface::Base, parent);
         Utils::JobHandler::install(job->kjob(), [storage, job, add] {
             if (job->kjob()->error() != KJob::NoError)
                 return;
@@ -193,19 +176,19 @@ LiveQueryHelpers::CollectionFetchFunction LiveQueryHelpers::fetchItemCollection(
 }
 
 
-LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchSiblings(const Item &item) const
+LiveQueryHelpers::ItemFetchFunction LiveQueryHelpers::fetchSiblings(const Item &item, QObject *parent) const
 {
     auto storage = m_storage;
-    return [storage, item] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
-        auto job = storage->fetchItem(item);
-        Utils::JobHandler::install(job->kjob(), [storage, job, add] {
+    return [storage, item, parent] (const Domain::LiveQueryInput<Item>::AddFunction &add) {
+        auto job = storage->fetchItem(item, parent);
+        Utils::JobHandler::install(job->kjob(), [storage, job, add, parent] {
             if (job->kjob()->error() != KJob::NoError)
                 return;
 
             Q_ASSERT(job->items().size() == 1);
             auto item = job->items().at(0);
             Q_ASSERT(item.parentCollection().isValid());
-            auto job = storage->fetchItems(item.parentCollection());
+            auto job = storage->fetchItems(item.parentCollection(), parent);
             Utils::JobHandler::install(job->kjob(), [job, add] {
                 if (job->kjob()->error() != KJob::NoError)
                     return;
