@@ -31,10 +31,12 @@ RunningTaskWidget::RunningTaskWidget(QWidget *parent)
     // This means no way to focus it with the keyboard, though, obviously.
 
     setWindowFlags(Qt::Window | Qt::BypassWindowManagerHint | Qt::FramelessWindowHint);
-    KX11Extras::setOnAllDesktops(winId(), true);
-    KWindowSystem::setState(winId(), NET::KeepAbove | NET::SkipTaskbar | NET::SkipPager);
+    if (KWindowSystem::isPlatformX11()) {
+        KX11Extras::setOnAllDesktops(winId(), true);
+        KX11Extras::setState(winId(), NET::KeepAbove | NET::SkipTaskbar | NET::SkipPager);
+    }
 
-    setWindowTitle(i18n("Zanshin Running Task Banner"));
+    setWindowTitle(i18nc("@title:window", "Zanshin Running Task Banner"));
 
     // Current idea for a good background color:
     // the selection color, i.e. usually blue. Arguable ;)
@@ -86,11 +88,7 @@ void RunningTaskWidget::setCollapsed(bool b)
     resize();
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void RunningTaskWidget::enterEvent(QEvent *)
-#else
 void RunningTaskWidget::enterEvent(QEnterEvent *)
-#endif
 {
     setCollapsed(false);
 }
@@ -138,3 +136,5 @@ QString RunningTaskWidget::currentText() const
 {
     return m_titleLabel->text();
 }
+
+#include "moc_runningtaskwidget.cpp"
