@@ -12,18 +12,14 @@
 
 #include "domain/taskrepository.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-using namespace Plasma;
-#else
 using namespace KRunner;
-#endif
 
 class ZanshinRunner : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    ZanshinRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ZanshinRunner(QObject *parent, const KPluginMetaData &metaData);
     ~ZanshinRunner();
 
 private:
